"use strict";
// could be the buffered signals object?
Object.defineProperty(exports, "__esModule", { value: true });
exports.createSignalsRuntime = void 0;
// This needs to use the function keyword so that it can be stringified and run in a sandbox
/**
 * @param signals - List of signals, with the most recent signals first (LIFO).
 */
function createSignalsRuntime(signals) {
    /**
     * @param fromSignal - signal to start searching from
     * @param signalType - type of signal to find (e.g. 'interaction')
     * @param predicate - optional predicate function to filter the signals (search domain only includes signals after the signal defined in `fromSignal`)
     * @returns signals after the current one.
     */
    function find(fromSignal, signalType, predicate) {
        const _isSignalOfType = (signal) => signal.type === signalType;
        return signals
            .slice(signals.indexOf(fromSignal) + 1)
            .filter(_isSignalOfType)
            .find((signal) => (predicate ? predicate(signal) : () => true));
    }
    /**
     * Filter signals - includes the current signal
     */
    function filter(...args) {
        return signals.filter(...args);
    }
    return {
        find,
        filter,
    };
}
exports.createSignalsRuntime = createSignalsRuntime;
//# sourceMappingURL=signals-runtime.js.map