"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.containsJSONContentType = exports.containsContentType = exports.isSameDomain = exports.getDomainFromHost = void 0;
/**
 * @example example.foo.bar.com => example.com
 * @example example.foo.co.uk => example.co.uk
 */
const getDomainFromHost = (hostName) => {
    const modified = hostName.replace('www.', '');
    const parts = modified.split('.');
    let offset = 2;
    if (
    // handle .co.uk, .com.au, .org.uk, .eu.com etc
    // this is a naive approach, but it's good enough for our use case
    ['co', 'com', 'org', 'eu'].includes(parts[parts.length - 2])) {
        offset = 3;
    }
    return parts.slice(-offset).join('.');
};
exports.getDomainFromHost = getDomainFromHost;
const isSameDomain = (url) => {
    // Relative URL like /foo/bar will always be considered same domain
    const rIsAbs = new RegExp('^(?:[a-z+]+:)?//', 'i');
    if (!rIsAbs.test(url)) {
        return true;
    }
    const host = new URL(url).hostname;
    return (0, exports.getDomainFromHost)(host) === (0, exports.getDomainFromHost)(window.location.hostname);
};
exports.isSameDomain = isSameDomain;
const normalizeHeaders = (headers) => {
    return headers instanceof Headers ? headers : new Headers(headers);
};
/**
 * @example expect(containsContentType(headers, ['application/json'])).toBe(true)
 */
const containsContentType = (headers, match) => {
    if (!headers) {
        return false;
    }
    const normalizedHeaders = normalizeHeaders(headers);
    // format the content-type header to remove charset -- this is non-standard behavior that is somewhat common
    // e.g. application/json;charset=utf-8 => application/json
    const removeCharset = (header) => header?.split(';')[0] ?? null;
    return match.some((t) => removeCharset(normalizedHeaders.get('content-type')) === t);
};
exports.containsContentType = containsContentType;
const containsJSONContentType = (headers) => {
    return (0, exports.containsContentType)(headers, ['application/json']);
};
exports.containsJSONContentType = containsJSONContentType;
//# sourceMappingURL=helpers.js.map